==> leoo_junpro-1.0.1.tar.gz: lib/leooimpjunpro/leoocamerajunpro/leoocamerajunpro.dart <==
import 'dart:async';

import 'package:camera/camera.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:image_picker/image_picker.dart';
import 'package:leoo_junpro/generated/l10n.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leooappconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leoonetconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoostringjunpro/leoostylejunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocodeutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocommonutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoodialogutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoomediautilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoonavigatorutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoovideoutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoowidgetutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoowidgetjunpro/leoocamerapreviewjunpro.dart';
import 'package:leoo_junpro/leooimpjunpro/leoocamerajunpro/leoouploadjunpro.dart';

///拍摄页面
class LeooCameraJunPro extends StatefulWidget {
  const LeooCameraJunPro({Key? key}) : super(key: key);

  @override
  _LeooCameraState createState() => _LeooCameraState();
}

class _LeooCameraState extends State<LeooCameraJunPro>
    with WidgetsBindingObserver {
  CameraController? cameraController;
  bool back = false;
  Timer? videoTimer;
  int currentTime = 0;
  int allTime = LeooAppConfigJunPro.leooVideoMaxTimeJunPro;

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance?.addObserver(this);
    initCamera();
  }

  @override
  void dispose() {
    WidgetsBinding.instance?.removeObserver(this);
    videoTimer?.cancel();
    cameraController?.dispose();
    cameraController = null;
    super.dispose();
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    if (state == AppLifecycleState.resumed) {
      initCamera();
    } else if (state == AppLifecycleState.paused) {
      cameraController?.dispose();
      cameraController = null;
      LeooCodeUtilsJunPro.onSetState(this);
    }
  }

  void startTime(bool start) {
    if (start) {
      videoTimer = Timer.periodic(const Duration(seconds: 1), (timer) {
        currentTime++;
        LeooCodeUtilsJunPro.onSetState(this);
        if (currentTime >= allTime) {
          videoTimer?.cancel();
          cameraFinish();
        }
      });
    } else {
      videoTimer?.cancel();
      LeooCodeUtilsJunPro.onSetState(this);
    }
  }

  void cameraFinish() async {
    try {
      XFile video = (await cameraController?.stopVideoRecording())!;
      Navigator.pop(context);
      LeooNavigatorUtilsJunPro.leooNavigatorPushJunPro(
          context, LeooUploadJunPro(video.path), 'LeooUploadJunPro');
    } catch (e) {
      LeooNetConfigJunPro.leooPrintLogJunPro(e);
    }
  }

  void initCamera() {
    Future.delayed(const Duration(seconds: 1), () async {
      LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
        LeooDialogUtilsJunPro.instance.showPermissionDialog(context,
            (value) async {
          try {
            if (value) {
              if (!LeooVideoUtilsJunPro.instance.isReception) {
                return;
              }
              cameraController = CameraController(
                  back
                      ? LeooMediaUtilsJunPro.instance.descriptionBack!
                      : LeooMediaUtilsJunPro.instance.description!,
                  ResolutionPreset.high);
              cameraController?.initialize().then((_) {
                if (!LeooVideoUtilsJunPro.instance.isReception) {
                  cameraController?.dispose();
                  cameraController = null;
                  return;
                }
                LeooCodeUtilsJunPro.onSetState(this);
              });
            }
          } catch (e) {
            LeooNetConfigJunPro.leooPrintLogJunPro(e);
          }
        });
      });
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      resizeToAvoidBottomInset: false,
      body: Stack(
        alignment: Alignment.topCenter,
        children: <Widget>[
          SizedBox(width: 1.sw, height: 1.sh),
          if (cameraController?.value.isInitialized == true)
            LeooCameraPreviewJunPro(cameraController!),
          cameraController?.value.isRecordingVideo != true &&
                  cameraController?.value.isRecordingPaused != true
              ? LeooWidgetUtilsJunPro.leooGetAppBarWidgetJunPro(context, '',
                  top: true)
              : Positioned(
                  top: ScreenUtil().statusBarHeight + 24.w,
                  left: 12.w,
                  right: 12.w,
                  child: LinearProgressIndicator(
                    value: currentTime / allTime,
                    valueColor:
                        const AlwaysStoppedAnimation<Color>(Colors.white),
                    backgroundColor: Colors.white.withOpacity(.5),
                  ),
                ),
          if (cameraController?.value.isRecordingVideo != true &&
              cameraController?.value.isRecordingPaused != true)
            Positioned(
              left: 50.w,
              bottom: ScreenUtil().bottomBarHeight + 70.w,
              child: IconButton(
                iconSize: 40.w,
                padding: const EdgeInsets.all(0),
                icon: LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                    LeooIconsJunPro.leooCameraSwitchJunPro,
                    width: 40.w,
                    height: 40.w),
                onPressed: LeooNavigatorUtilsJunPro.leooDebounceJunPro(() {
                  back = !back;
                  initCamera();
                }),
              ),
            ),
          Positioned(
            bottom: ScreenUtil().bottomBarHeight + 50.w,
            child: IconButton(
              iconSize: 90.w,
              padding: const EdgeInsets.all(0),
              icon: LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                  cameraController?.value.isRecordingVideo == false ||
                          cameraController?.value.isRecordingPaused == true
                      ? LeooIconsJunPro.leooCameraStartJunPro
                      : LeooIconsJunPro.leooCameraStopJunPro,
                  width: 90.w,
                  height: 90.w),
              onPressed: LeooNavigatorUtilsJunPro.leooDebounceJunPro(() async {
                if (cameraController?.value.isRecordingPaused == true) {
                  await cameraController?.resumeVideoRecording();
                  startTime(true);
                } else if (cameraController?.value.isRecordingVideo == true) {
                  await cameraController?.pauseVideoRecording();
                  startTime(false);
                } else {
                  await cameraController?.startVideoRecording();
                  currentTime = 0;
                  startTime(true);
                }
              }),
            ),
          ),
          Positioned(
            right: 50.w,
            bottom: ScreenUtil().bottomBarHeight + 70.w,
            child: IconButton(
              iconSize: 40.w,
              padding: const EdgeInsets.all(0),
              icon: LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                  cameraController?.value.isRecordingVideo == true ||
                          cameraController?.value.isRecordingPaused == true
                      ? LeooIconsJunPro.leooApplyOkJunPro
                      : LeooIconsJunPro.leooCameraUploadJunPro,
                  width: 40.w,
                  height: 40.w),
              onPressed: LeooNavigatorUtilsJunPro.leooDebounceJunPro(() async {
                if (cameraController?.value.isRecordingVideo == true ||
                    cameraController?.value.isRecordingPaused == true) {
                  cameraFinish();
                } else {
                  XFile? video = await ImagePicker()
                      .pickVideo(source: ImageSource.gallery)
                      .catchError((err) {
                    LeooCommonUtilsJunPro.leooShowCustomToastJunPro(
                        err.message);
                  });
                  if (video != null) {
                    if (video.path.contains(' ')) {
                      LeooCommonUtilsJunPro.leooShowCustomToastJunPro(
                          S.of(context).perPicErrorFormat);
                      return;
                    }
                    Navigator.pop(context);
                    LeooNavigatorUtilsJunPro.leooNavigatorPushJunPro(context,
                        LeooUploadJunPro(video.path), 'LeooUploadJunPro');
                  }
                }
              }),
            ),
          ),
        ],
      ),
    );
  }
}

==> leoo_junpro-2.0.0.tar.gz: lib/leooimpjunpro/leoocamerajunpro/leoocamerajunpro.dart <==
import 'dart:async';

import 'package:camera/camera.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:image_picker/image_picker.dart';
import 'package:leoo_junpro/generated/l10n.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leooappconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leoonetconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoostringjunpro/leoostylejunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocodeutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocommonutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoodialogutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoomediautilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoonavigatorutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoovideoutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoowidgetutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoowidgetjunpro/leoocamerapreviewjunpro.dart';
import 'package:leoo_junpro/leooimpjunpro/leoocamerajunpro/leoouploadjunpro.dart';

///拍摄页面
class LeooCameraJunPro extends StatefulWidget {
  const LeooCameraJunPro({Key? key}) : super(key: key);

  @override
  _LeooCameraState createState() => _LeooCameraState();
}

class _LeooCameraState extends State<LeooCameraJunPro>
    with WidgetsBindingObserver {
  CameraController? cameraController;
  bool back = false;
  Timer? videoTimer;
  int currentTime = 0;
  int allTime = LeooAppConfigJunPro.leooVideoMaxTimeJunPro;

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance.addObserver(this);
    initCamera();
  }

  @override
  void dispose() {
    WidgetsBinding.instance.removeObserver(this);
    videoTimer?.cancel();
    cameraController?.dispose();
    cameraController = null;
    super.dispose();
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    if (state == AppLifecycleState.resumed) {
      initCamera();
    } else if (state == AppLifecycleState.paused) {
      cameraController?.dispose();
      cameraController = null;
      LeooCodeUtilsJunPro.onSetState(this);
    }
  }

  void startTime(bool start) {
    if (start) {
      videoTimer = Timer.periodic(const Duration(seconds: 1), (timer) {
        currentTime++;
        LeooCodeUtilsJunPro.onSetState(this);
        if (currentTime >= allTime) {
          videoTimer?.cancel();
          cameraFinish();
        }
      });
    } else {
      videoTimer?.cancel();
      LeooCodeUtilsJunPro.onSetState(this);
    }
  }

  void cameraFinish() async {
    try {
      XFile video = (await cameraController?.stopVideoRecording())!;
      Navigator.pop(context);
      LeooNavigatorUtilsJunPro.leooNavigatorPushJunPro(
          context, LeooUploadJunPro(video.path), 'LeooUploadJunPro');
    } catch (e) {
      LeooNetConfigJunPro.leooPrintLogJunPro(e);
    }
  }

  void initCamera() {
    Future.delayed(const Duration(seconds: 1), () async {
      LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
        LeooDialogUtilsJunPro.instance.showPermissionDialog(context,
            (value) async {
          try {
            if (value) {
              if (!LeooVideoUtilsJunPro.instance.isReception) {
                return;
              }
              cameraController = CameraController(
                  back
                      ? LeooMediaUtilsJunPro.instance.descriptionBack!
                      : LeooMediaUtilsJunPro.instance.description!,
                  ResolutionPreset.high);
              cameraController?.initialize().then((_) {
                if (!LeooVideoUtilsJunPro.instance.isReception) {
                  cameraController?.dispose();
                  cameraController = null;
                  return;
                }
                LeooCodeUtilsJunPro.onSetState(this);
              });
            }
          } catch (e) {
            LeooNetConfigJunPro.leooPrintLogJunPro(e);
          }
        });
      });
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      resizeToAvoidBottomInset: false,
      body: Stack(
        alignment: Alignment.topCenter,
        children: <Widget>[
          SizedBox(width: 1.sw, height: 1.sh),
          if (cameraController?.value.isInitialized == true)
            LeooCameraPreviewJunPro(cameraController!),
          cameraController?.value.isRecordingVideo != true &&
                  cameraController?.value.isRecordingPaused != true
              ? LeooWidgetUtilsJunPro.leooGetAppBarWidgetJunPro(context, '',
                  top: true)
              : Positioned(
                  top: ScreenUtil().statusBarHeight + 24.w,
                  left: 12.w,
                  right: 12.w,
                  child: LinearProgressIndicator(
                    value: currentTime / allTime,
                    valueColor:
                        const AlwaysStoppedAnimation<Color>(Colors.white),
                    backgroundColor: Colors.white.withOpacity(.5),
                  ),
                ),
          if (cameraController?.value.isRecordingVideo != true &&
              cameraController?.value.isRecordingPaused != true)
            Positioned(
              left: 50.w,
              bottom: ScreenUtil().bottomBarHeight + 70.w,
              child: IconButton(
                iconSize: 40.w,
                padding: const EdgeInsets.all(0),
                icon: LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                    LeooIconsJunPro.leooCameraSwitchJunPro,
                    width: 40.w,
                    height: 40.w),
                onPressed: LeooNavigatorUtilsJunPro.leooDebounceJunPro(() {
                  back = !back;
                  initCamera();
                }),
              ),
            ),
          Positioned(
            bottom: ScreenUtil().bottomBarHeight + 50.w,
            child: IconButton(
              iconSize: 90.w,
              padding: const EdgeInsets.all(0),
              icon: LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                  cameraController?.value.isRecordingVideo == false ||
                          cameraController?.value.isRecordingPaused == true
                      ? LeooIconsJunPro.leooCameraStartJunPro
                      : LeooIconsJunPro.leooCameraStopJunPro,
                  width: 90.w,
                  height: 90.w),
              onPressed: LeooNavigatorUtilsJunPro.leooDebounceJunPro(() async {
                if (cameraController?.value.isRecordingPaused == true) {
                  await cameraController?.resumeVideoRecording();
                  startTime(true);
                } else if (cameraController?.value.isRecordingVideo == true) {
                  await cameraController?.pauseVideoRecording();
                  startTime(false);
                } else {
                  await cameraController?.startVideoRecording();
                  currentTime = 0;
                  startTime(true);
                }
              }),
            ),
          ),
          Positioned(
            right: 50.w,
            bottom: ScreenUtil().bottomBarHeight + 70.w,
            child: IconButton(
              iconSize: 40.w,
              padding: const EdgeInsets.all(0),
              icon: LeooCommonUtilsJunPro.leooGetLoadWidgetJunPro(
                  cameraController?.value.isRecordingVideo == true ||
                          cameraController?.value.isRecordingPaused == true
                      ? LeooIconsJunPro.leooApplyOkJunPro
                      : LeooIconsJunPro.leooCameraUploadJunPro,
                  width: 40.w,
                  height: 40.w),
              onPressed: LeooNavigatorUtilsJunPro.leooDebounceJunPro(() async {
                if (cameraController?.value.isRecordingVideo == true ||
                    cameraController?.value.isRecordingPaused == true) {
                  cameraFinish();
                } else {
                  XFile? video = await ImagePicker()
                      .pickVideo(source: ImageSource.gallery)
                      .catchError((err) {
                    LeooCommonUtilsJunPro.leooShowCustomToastJunPro(
                        err.message);
                  });
                  if (video != null) {
                    if (video.path.contains(' ')) {
                      LeooCommonUtilsJunPro.leooShowCustomToastJunPro(
                          S.of(context).perPicErrorFormat);
                      return;
                    }
                    Navigator.pop(context);
                    LeooNavigatorUtilsJunPro.leooNavigatorPushJunPro(context,
                        LeooUploadJunPro(video.path), 'LeooUploadJunPro');
                  }
                }
              }),
            ),
          ),
        ],
      ),
    );
  }
}
